MCALF utils
***********

This sub-package contains:

* Functions for processing spectra (`mcalf.utils.spec`).
* Functions for smoothing n-dimensional arrays
  (`mcalf.utils.smooth`).
* Functions for masking the input data to limit the
  region computed (`mcalf.utils.mask`).
* Functions for helping with plotting (`mcalf.utils.plot`).
* Classes for managing collections of data (`mcalf.utils.collections`).
* Miscellaneous utility functions (`mcalf.utils.misc`).

.. automodapi:: mcalf.utils

.. automodapi:: mcalf.utils.spec

.. automodapi:: mcalf.utils.smooth

.. automodapi:: mcalf.utils.mask

.. automodapi:: mcalf.utils.plot

.. automodapi:: mcalf.utils.collections

.. automodapi:: mcalf.utils.misc
